==> qms-angular-1.0.88.tgz: package/src/assets/qms-ckeditor-plugin/src/ckeditor.js <==
/**
 * @license Copyright (c) 2014-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
import CKFinderUploadAdapter from '@ckeditor/ckeditor5-adapter-ckfinder/src/uploadadapter.js';
import Alignment from '@ckeditor/ckeditor5-alignment/src/alignment.js';
import Autoformat from '@ckeditor/ckeditor5-autoformat/src/autoformat.js';
import Bold from '@ckeditor/ckeditor5-basic-styles/src/bold.js';
import Italic from '@ckeditor/ckeditor5-basic-styles/src/italic.js';
import Strikethrough from '@ckeditor/ckeditor5-basic-styles/src/strikethrough.js';
import Underline from '@ckeditor/ckeditor5-basic-styles/src/underline.js';
import BlockQuote from '@ckeditor/ckeditor5-block-quote/src/blockquote.js';
import CKFinder from '@ckeditor/ckeditor5-ckfinder/src/ckfinder.js';
import ClassicEditor from '@ckeditor/ckeditor5-editor-classic/src/classiceditor.js';
import Essentials from '@ckeditor/ckeditor5-essentials/src/essentials.js';
import Font from '@ckeditor/ckeditor5-font/src/font.js';
import Heading from '@ckeditor/ckeditor5-heading/src/heading.js';
import Image from '@ckeditor/ckeditor5-image/src/image.js';
import ImageCaption from '@ckeditor/ckeditor5-image/src/imagecaption.js';
import ImageResize from '@ckeditor/ckeditor5-image/src/imageresize.js';
import ImageStyle from '@ckeditor/ckeditor5-image/src/imagestyle.js';
import ImageToolbar from '@ckeditor/ckeditor5-image/src/imagetoolbar.js';
import ImageUpload from '@ckeditor/ckeditor5-image/src/imageupload.js';
import List from '@ckeditor/ckeditor5-list/src/list.js';
import Paragraph from '@ckeditor/ckeditor5-paragraph/src/paragraph.js';
import PasteFromOffice from '@ckeditor/ckeditor5-paste-from-office/src/pastefromoffice';
import Table from './plugins/table/table.js';
import TableProperties from './plugins/table/tableproperties';
import TableCellProperties from './plugins/table/tablecellproperties.js';
import TableSelection from './plugins/table/tableselection.js';
import TableToolbar from './plugins/table/tabletoolbar.js';
import TextTransformation from '@ckeditor/ckeditor5-typing/src/texttransformation.js';
import WordCount from '@ckeditor/ckeditor5-word-count/src/wordcount';
import Anchor from './plugins/anchor/anchor.js';
import QMSCKEditorFullscreenPlugin from './plugins/fullscreen/qmsCKEditorFullscreenPlugin.js';
import Link from './plugins/link/link.js';
import LinkImage from './plugins/link/linkimage.js';
import MediaEmbed from './plugins/media/mediaembed.js';
import MediaToolbar from './plugins/media/mediaembedtoolbar.js';
import MediaResize from './plugins/media/mediaresize.js';
import MediaStyle from './plugins/media/mediastyle.js';
import QMSCKEditorLoadTemplatePlugin from './plugins/template/qmsCKEditorLoadTemplatePlugin.js';
import QMSCKEditorTemplatePlugin from './plugins/template/qmsCKEdtiorTemplatePlugin.js';
import Video from './plugins/video/video.js';
import VideoResize from './plugins/video/videoresize.js';
import VideoStyle from './plugins/video/videostyle.js';
import VideoToolbar from './plugins/video/videotoolbar.js';
import VideoUpload from './plugins/video/videoupload.js';
import RemoveFormat from '@ckeditor/ckeditor5-remove-format/src/removeformat.js';
import Superscript from '@ckeditor/ckeditor5-basic-styles/src/superscript.js';
import Subscript from '@ckeditor/ckeditor5-basic-styles/src/subscript.js';
//import MathType from '@wiris/mathtype-ckeditor5';
import Timestamp from './plugins/timestamp/timestamp.js';
import SpecialCharacters from './plugins/ckeditor5-special-characters/src/specialcharacters.js';
import SpecialCharactersArrows from './plugins/ckeditor5-special-characters/src/specialcharactersarrows.js';
import specialcharacterscurrency from './plugins/ckeditor5-special-characters/src/specialcharacterscurrency.js';
import SpecialCharactersLatin from './plugins/ckeditor5-special-characters/src/specialcharacterslatin.js';
import SpecialCharactersText from './plugins/ckeditor5-special-characters/src/specialcharacterstext.js';
import SpecialCharactersMathematical from './plugins/ckeditor5-special-characters/src/specialcharactersmathematical.js';
import Clipboard from '@ckeditor/ckeditor5-clipboard/src/clipboard';
import FindAndReplace from './plugins/ckeditor5-find-and-replace/src/findandreplace.js';
import Tooltip from './plugins/tooltip/tooltip.js';
import PageBreak from '@ckeditor/ckeditor5-page-break/src/pagebreak';
import ImageMap from './plugins/imagemap/imagemap.js';
import Indent from '@ckeditor/ckeditor5-indent/src/indent';
import IndentBlock from '@ckeditor/ckeditor5-indent/src/indentblock';
import HorizontalLine from '@ckeditor/ckeditor5-horizontal-line/src/horizontalline';
import ToggleToolbar from './plugins/toggletoolbar/toggletoolbar.js';
import QMSCKEditorBpmnPlugin from './plugins/bpmn/qmsCKEditorBpmnPlugin.js';
import QMSCKEditorFlowchartPlugin from './plugins/flowchart/qmsCKEditorFlowchartPlugin.js';
import TableOfContents from './plugins/tableofcontents/tableofcontents';
import AboutCKEditor from './plugins/aboutckeditor/aboutckeditor.js';
//import WProofreader from '@webspellchecker/wproofreader-ckeditor5/src/wproofreader';
import SourceEditing from './plugins/ckeditor5-source-editing/src/sourceediting';

class Editor extends ClassicEditor {}

// Plugins to include in the build.
Editor.builtinPlugins = [
	Alignment,
	Autoformat,
	BlockQuote,
	Bold,
	CKFinder,
	CKFinderUploadAdapter,
	Essentials,
	Font,
	Heading,
	Image,
	ImageCaption,
	ImageResize,
	ImageStyle,
	ImageToolbar,
	ImageUpload,
	Italic,
	Underline,
	Strikethrough,
	Link,
	LinkImage,
	List,
	MediaEmbed,
	MediaToolbar,
	MediaResize,
	MediaStyle,
	Paragraph,
	Table,
	TableToolbar,
	TableProperties,
	TableCellProperties,
	TableSelection,
	TextTransformation,
	QMSCKEditorFullscreenPlugin,
	QMSCKEditorTemplatePlugin,
	QMSCKEditorLoadTemplatePlugin,
	Anchor,
	Video,
	VideoResize,
	VideoStyle,
	VideoToolbar,
	VideoUpload,
	WordCount,
  	RemoveFormat,
	Superscript,
	Subscript,
	//MathType,
	Timestamp,
	SpecialCharacters,
	SpecialCharactersArrows,
	specialcharacterscurrency,
	SpecialCharactersLatin,
	SpecialCharactersText,
	SpecialCharactersMathematical,
	Clipboard,
	PasteFromOffice,
	Tooltip,
	FindAndReplace,
	PageBreak,
	ImageMap,
	PageBreak,
	Indent,
	IndentBlock,
	HorizontalLine,
	QMSCKEditorBpmnPlugin,
	AboutCKEditor,
	QMSCKEditorFlowchartPlugin,
	ToggleToolbar,
	TableOfContents,
	//WProofreader,
  SourceEditing
];

export default Editor;

==> qms-angular-2.0.10.tgz: package/src/assets/qms-ckeditor-plugin/src/ckeditor.js <==
/**
 * @license Copyright (c) 2014-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
import CKFinderUploadAdapter from '@ckeditor/ckeditor5-adapter-ckfinder/src/uploadadapter.js';
import Alignment from '@ckeditor/ckeditor5-alignment/src/alignment.js';
import Autoformat from '@ckeditor/ckeditor5-autoformat/src/autoformat.js';
import Bold from '@ckeditor/ckeditor5-basic-styles/src/bold.js';
import Italic from '@ckeditor/ckeditor5-basic-styles/src/italic.js';
import Strikethrough from '@ckeditor/ckeditor5-basic-styles/src/strikethrough.js';
import Underline from '@ckeditor/ckeditor5-basic-styles/src/underline.js';
import BlockQuote from '@ckeditor/ckeditor5-block-quote/src/blockquote.js';
import CKFinder from '@ckeditor/ckeditor5-ckfinder/src/ckfinder.js';
import ClassicEditor from '@ckeditor/ckeditor5-editor-classic/src/classiceditor.js';
import Essentials from '@ckeditor/ckeditor5-essentials/src/essentials.js';
import Font from '@ckeditor/ckeditor5-font/src/font.js';
import Heading from './plugins/heading/heading.js';
import Image from '@ckeditor/ckeditor5-image/src/image.js';
import ImageCaption from '@ckeditor/ckeditor5-image/src/imagecaption.js';
import ImageResize from '@ckeditor/ckeditor5-image/src/imageresize.js';
import ImageStyle from '@ckeditor/ckeditor5-image/src/imagestyle.js';
import ImageToolbar from '@ckeditor/ckeditor5-image/src/imagetoolbar.js';
import ImageUpload from '@ckeditor/ckeditor5-image/src/imageupload.js';
import List from '@ckeditor/ckeditor5-list/src/list.js';
import Paragraph from '@ckeditor/ckeditor5-paragraph/src/paragraph.js';
import PasteFromOffice from '@ckeditor/ckeditor5-paste-from-office/src/pastefromoffice';
import Table from './plugins/table/table.js';
import TableProperties from './plugins/table/tableproperties';
import TableCellProperties from './plugins/table/tablecellproperties.js';
import TableSelection from './plugins/table/tableselection.js';
import TableToolbar from './plugins/table/tabletoolbar.js';
import TextTransformation from '@ckeditor/ckeditor5-typing/src/texttransformation.js';
import WordCount from '@ckeditor/ckeditor5-word-count/src/wordcount';
import Anchor from './plugins/anchor/anchor.js';
import QMSCKEditorFullscreenPlugin from './plugins/fullscreen/qmsCKEditorFullscreenPlugin.js';
import Link from './plugins/link/link.js';
import LinkImage from './plugins/link/linkimage.js';
import MediaEmbed from './plugins/media/mediaembed.js';
import MediaToolbar from './plugins/media/mediaembedtoolbar.js';
import MediaResize from './plugins/media/mediaresize.js';
import MediaStyle from './plugins/media/mediastyle.js';
import QMSCKEditorLoadTemplatePlugin from './plugins/template/qmsCKEditorLoadTemplatePlugin.js';
import QMSCKEditorTemplatePlugin from './plugins/template/qmsCKEdtiorTemplatePlugin.js';
import Video from './plugins/video/video.js';
import VideoResize from './plugins/video/videoresize.js';
import VideoStyle from './plugins/video/videostyle.js';
import VideoToolbar from './plugins/video/videotoolbar.js';
import VideoUpload from './plugins/video/videoupload.js';
import RemoveFormat from '@ckeditor/ckeditor5-remove-format/src/removeformat.js';
import Superscript from '@ckeditor/ckeditor5-basic-styles/src/superscript.js';
import Subscript from '@ckeditor/ckeditor5-basic-styles/src/subscript.js';
//import MathType from '@wiris/mathtype-ckeditor5';
import Timestamp from './plugins/timestamp/timestamp.js';
import SpecialCharacters from './plugins/ckeditor5-special-characters/src/specialcharacters.js';
import SpecialCharactersArrows from './plugins/ckeditor5-special-characters/src/specialcharactersarrows.js';
import specialcharacterscurrency from './plugins/ckeditor5-special-characters/src/specialcharacterscurrency.js';
import SpecialCharactersLatin from './plugins/ckeditor5-special-characters/src/specialcharacterslatin.js';
import SpecialCharactersText from './plugins/ckeditor5-special-characters/src/specialcharacterstext.js';
import SpecialCharactersMathematical from './plugins/ckeditor5-special-characters/src/specialcharactersmathematical.js';
import Clipboard from '@ckeditor/ckeditor5-clipboard/src/clipboard';
import FindAndReplace from './plugins/ckeditor5-find-and-replace/src/findandreplace.js';
import Tooltip from './plugins/tooltip/tooltip.js';
import PageBreak from '@ckeditor/ckeditor5-page-break/src/pagebreak';
import ImageMap from './plugins/imagemap/imagemap.js';
import Indent from '@ckeditor/ckeditor5-indent/src/indent';
import IndentBlock from '@ckeditor/ckeditor5-indent/src/indentblock';
import HorizontalLine from '@ckeditor/ckeditor5-horizontal-line/src/horizontalline';
import ToggleToolbar from './plugins/toggletoolbar/toggletoolbar.js';
import QMSCKEditorBpmnPlugin from './plugins/bpmn/qmsCKEditorBpmnPlugin.js';
import QMSCKEditorFlowchartPlugin from './plugins/flowchart/qmsCKEditorFlowchartPlugin.js';
import TableOfContents from './plugins/tableofcontents/tableofcontents';
import AboutCKEditor from './plugins/aboutckeditor/aboutckeditor.js';
//import WProofreader from '@webspellchecker/wproofreader-ckeditor5/src/wproofreader';
import SourceEditing from './plugins/ckeditor5-source-editing/src/sourceediting';

class Editor extends ClassicEditor {}

// Plugins to include in the build.
Editor.builtinPlugins = [
	Alignment,
	Autoformat,
	BlockQuote,
	Bold,
	CKFinder,
	CKFinderUploadAdapter,
	Essentials,
	Font,
	Heading,
	Image,
	ImageCaption,
	ImageResize,
	ImageStyle,
	ImageToolbar,
	ImageUpload,
	Italic,
	Underline,
	Strikethrough,
	Link,
	LinkImage,
	List,
	MediaEmbed,
	MediaToolbar,
	MediaResize,
	MediaStyle,
	Paragraph,
	Table,
	TableToolbar,
	TableProperties,
	TableCellProperties,
	TableSelection,
	TextTransformation,
	QMSCKEditorFullscreenPlugin,
	QMSCKEditorTemplatePlugin,
	QMSCKEditorLoadTemplatePlugin,
	Anchor,
	Video,
	VideoResize,
	VideoStyle,
	VideoToolbar,
	VideoUpload,
	WordCount,
  	RemoveFormat,
	Superscript,
	Subscript,
	//MathType,
	Timestamp,
	SpecialCharacters,
	SpecialCharactersArrows,
	specialcharacterscurrency,
	SpecialCharactersLatin,
	SpecialCharactersText,
	SpecialCharactersMathematical,
	Clipboard,
	PasteFromOffice,
	Tooltip,
	FindAndReplace,
	PageBreak,
	ImageMap,
	PageBreak,
	Indent,
	IndentBlock,
	HorizontalLine,
	QMSCKEditorBpmnPlugin,
	AboutCKEditor,
	QMSCKEditorFlowchartPlugin,
	ToggleToolbar,
	TableOfContents,
	//WProofreader,
  SourceEditing
];

export default Editor;
